@@ -86,10 +86,10 @@ use strict;
 
 use Authen::Passphrase 0.003;
 use Carp qw(croak);
-use Crypt::Eksblowfish::Bcrypt 0.000 qw(bcrypt_hash en_base64 de_base64);
+use Crypt::Eksblowfish::Bcrypt 0.005 qw(bcrypt_hash en_base64 de_base64);
 use Data::Entropy::Algorithms 0.000 qw(rand_bits);
 
-our $VERSION = "0.004";
+our $VERSION = "0.006";
 
 use base qw(Authen::Passphrase);
 use fields qw(key_nul cost salt hash);
@@ -152,9 +152,9 @@ The cost and salt must be given, and either the hash or the passphrase.
 
 =cut
 
-sub new($@) {
+sub new {
 	my $class = shift;
-	my __PACKAGE__ $self = fields::new($class);
+	my Authen::Passphrase::BlowfishCrypt $self = fields::new($class);
 	my $passphrase;
 	while(@_) {
 		my $attr = shift;
@@ -172,7 +172,7 @@ sub new($@) {
 		} elsif($attr eq "salt") {
 			croak "salt specified redundantly"
 				if exists $self->{salt};
-			$value =~ m#\A[\x{0}-\x{ff}]{16}\z#
+			$value =~ m#\A[\x00-\xff]{16}\z#
 				or croak "\"$value\" is not a valid raw salt";
 			$self->{salt} = "$value";
 		} elsif($attr eq "salt_base64") {
@@ -189,7 +189,7 @@ sub new($@) {
 			croak "hash specified redundantly"
 				if exists($self->{hash}) ||
 					defined($passphrase);
-			$value =~ m#\A[\x{0}-\x{ff}]{23}\z#
+			$value =~ m#\A[\x00-\xff]{23}\z#
 				or croak "not a valid raw hash";
 			$self->{hash} = "$value";
 		} elsif($attr eq "hash_base64") {
@@ -227,7 +227,7 @@ digits giving the salt, and finally 31 base 64 digits giving the hash.
 
 =cut
 
-sub from_crypt($$) {
+sub from_crypt {
 	my($class, $passwd) = @_;
 	if($passwd =~ /\A(\$2a?\$)/) {
 		$passwd =~ m#\A\$2(a?)\$([0-9]{2})\$
@@ -258,8 +258,8 @@ passphrase before using it as a key.
 
 =cut
 
-sub key_nul($) {
-	my __PACKAGE__ $self = shift;
+sub key_nul {
+	my Authen::Passphrase::BlowfishCrypt $self = shift;
 	return $self->{key_nul};
 }
 
@@ -270,8 +270,8 @@ be performed.
 
 =cut
 
-sub cost($) {
-	my __PACKAGE__ $self = shift;
+sub cost {
+	my Authen::Passphrase::BlowfishCrypt $self = shift;
 	return $self->{cost};
 }
 
@@ -289,8 +289,8 @@ Returns the salt, as a string of sixteen bytes.
 
 =cut
 
-sub salt($) {
-	my __PACKAGE__ $self = shift;
+sub salt {
+	my Authen::Passphrase::BlowfishCrypt $self = shift;
 	return $self->{salt};
 }
 
@@ -300,8 +300,8 @@ Returns the salt, as a string of 22 base 64 digits.
 
 =cut
 
-sub salt_base64($) {
-	my __PACKAGE__ $self = shift;
+sub salt_base64 {
+	my Authen::Passphrase::BlowfishCrypt $self = shift;
 	return en_base64($self->{salt});
 }
 
@@ -311,8 +311,8 @@ Returns the hash value, as a string of 23 bytes.
 
 =cut
 
-sub hash($) {
-	my __PACKAGE__ $self = shift;
+sub hash {
+	my Authen::Passphrase::BlowfishCrypt $self = shift;
 	return $self->{hash};
 }
 
@@ -322,8 +322,8 @@ Returns the hash value, as a string of 31 base 64 digits.
 
 =cut
 
-sub hash_base64($) {
-	my __PACKAGE__ $self = shift;
+sub hash_base64 {
+	my Authen::Passphrase::BlowfishCrypt $self = shift;
 	return en_base64($self->{hash});
 }
 
@@ -337,8 +337,8 @@ These methods are part of the standard C<Authen::Passphrase> interface.
 
 =cut
 
-sub _hash_of($$) {
-	my __PACKAGE__ $self = shift;
+sub _hash_of {
+	my Authen::Passphrase::BlowfishCrypt $self = shift;
 	my($passphrase) = @_;
 	return bcrypt_hash({
 		key_nul => $self->{key_nul},
@@ -347,14 +347,14 @@ sub _hash_of($$) {
 	}, $passphrase);
 }
 
-sub match($$) {
-	my __PACKAGE__ $self = shift;
+sub match {
+	my Authen::Passphrase::BlowfishCrypt $self = shift;
 	my($passphrase) = @_;
 	return $self->_hash_of($passphrase) eq $self->{hash};
 }
 
-sub as_crypt($) {
-	my __PACKAGE__ $self = shift;
+sub as_crypt {
+	my Authen::Passphrase::BlowfishCrypt $self = shift;
 	croak "passphrase can't be expressed as a crypt string"
 		if $self->{cost} > 99;
 	return sprintf("\$2%s\$%02d\$%s%s", $self->key_nul ? "a" : "",
@@ -374,7 +374,9 @@ Andrew Main (Zefram) <zefram@fysh.org>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2006 Andrew Main (Zefram) <zefram@fysh.org>
+Copyright (C) 2006, 2007, 2009 Andrew Main (Zefram) <zefram@fysh.org>
+
+=head1 LICENSE
 
 This module is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
