@@ -47,7 +47,7 @@ use Authen::Passphrase 0.003;
 use Carp qw(croak);
 use Crypt::MySQL 0.03 qw(password);
 
-our $VERSION = "0.004";
+our $VERSION = "0.006";
 
 use base qw(Authen::Passphrase);
 use fields qw(hash);
@@ -82,9 +82,9 @@ Either the hash or the passphrase must be given.
 
 =cut
 
-sub new($@) {
+sub new {
 	my $class = shift;
-	my __PACKAGE__ $self = fields::new($class);
+	my Authen::Passphrase::MySQL323 $self = fields::new($class);
 	my $passphrase;
 	while(@_) {
 		my $attr = shift;
@@ -130,8 +130,8 @@ Returns the hash value, as a string of eight bytes.
 
 =cut
 
-sub hash($) {
-	my __PACKAGE__ $self = shift;
+sub hash {
+	my Authen::Passphrase::MySQL323 $self = shift;
 	return $self->{hash};
 }
 
@@ -141,8 +141,8 @@ Returns the hash value, as a string of 16 hexadecimal digits.
 
 =cut
 
-sub hash_hex($) {
-	my __PACKAGE__ $self = shift;
+sub hash_hex {
+	my Authen::Passphrase::MySQL323 $self = shift;
 	return unpack("H*", $self->{hash});
 }
 
@@ -152,14 +152,14 @@ This method is part of the standard C<Authen::Passphrase> interface.
 
 =cut
 
-sub _hash_of($$) {
-	my __PACKAGE__ $self = shift;
+sub _hash_of {
+	my Authen::Passphrase::MySQL323 $self = shift;
 	my($passphrase) = @_;
 	return pack("H*", password($passphrase));
 }
 
-sub match($$) {
-	my __PACKAGE__ $self = shift;
+sub match {
+	my Authen::Passphrase::MySQL323 $self = shift;
 	my($passphrase) = @_;
 	return $self->_hash_of($passphrase) eq $self->{hash};
 }
@@ -177,7 +177,9 @@ Andrew Main (Zefram) <zefram@fysh.org>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2006 Andrew Main (Zefram) <zefram@fysh.org>
+Copyright (C) 2006, 2007, 2009 Andrew Main (Zefram) <zefram@fysh.org>
+
+=head1 LICENSE
 
 This module is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
