@@ -47,7 +47,7 @@ use Authen::Passphrase 0.003;
 use Carp qw(croak);
 use Digest::SHA1 qw(sha1);
 
-our $VERSION = "0.004";
+our $VERSION = "0.006";
 
 use base qw(Authen::Passphrase);
 use fields qw(hash);
@@ -81,9 +81,9 @@ Either the hash or the passphrase must be given.
 
 =cut
 
-sub new($@) {
+sub new {
 	my $class = shift;
-	my __PACKAGE__ $self = fields::new($class);
+	my Authen::Passphrase::MySQL41 $self = fields::new($class);
 	my $passphrase;
 	while(@_) {
 		my $attr = shift;
@@ -129,8 +129,8 @@ Returns the hash value, as a string of 20 bytes.
 
 =cut
 
-sub hash($) {
-	my __PACKAGE__ $self = shift;
+sub hash {
+	my Authen::Passphrase::MySQL41 $self = shift;
 	return $self->{hash};
 }
 
@@ -140,8 +140,8 @@ Returns the hash value, as a string of 40 uppercase hexadecimal digits.
 
 =cut
 
-sub hash_hex($) {
-	my __PACKAGE__ $self = shift;
+sub hash_hex {
+	my Authen::Passphrase::MySQL41 $self = shift;
 	return uc(unpack("H*", $self->{hash}));
 }
 
@@ -151,14 +151,14 @@ This method is part of the standard C<Authen::Passphrase> interface.
 
 =cut
 
-sub _hash_of($$) {
-	my __PACKAGE__ $self = shift;
+sub _hash_of {
+	my Authen::Passphrase::MySQL41 $self = shift;
 	my($passphrase) = @_;
 	return sha1(sha1($passphrase));
 }
 
-sub match($$) {
-	my __PACKAGE__ $self = shift;
+sub match {
+	my Authen::Passphrase::MySQL41 $self = shift;
 	my($passphrase) = @_;
 	return $self->_hash_of($passphrase) eq $self->{hash};
 }
@@ -176,7 +176,9 @@ Andrew Main (Zefram) <zefram@fysh.org>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2006 Andrew Main (Zefram) <zefram@fysh.org>
+Copyright (C) 2006, 2007, 2009 Andrew Main (Zefram) <zefram@fysh.org>
+
+=head1 LICENSE
 
 This module is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
